%global with_debug 1

%if 0%{?with_debug}
%global _find_debuginfo_dwz_opts %{nil}
%global _dwz_low_mem_die_limit 0
%else
%global debug_package %{nil}
%endif

%if 0%{?fedora}
%define gobuild(o:) go build -buildmode pie -compiler gc -tags="rpm_crashtraceback ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-} -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags'" -a -v -x %{?**};
%else
%if 0%{?rhel} > 7
%define gobuild(o:) go build -buildmode pie -compiler gc -tags="rpm_crashtraceback libtrust_openssl ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-} -compressdwarf=false -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags'" -a -v -x %{?**};
%else
# Golang minor version
%define gominver 15
%define gobuild(o:) scl enable go-toolset-1.%{gominver} -- go build -buildmode pie -compiler gc -tags="rpm_crashtraceback libtrust_openssl ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-} -compressdwarf=false -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags'" -a -v -x %{?**};
%endif
%endif

%global provider github
%global provider_tld com
%global project cri-o
%global repo cri-o
# https://github.com/cri-o/cri-o
%global import_path %{provider}.%{provider_tld}/%{project}/%{repo}
%global commit0 ec973a297fbfb01708b83c6bcd1bdf67847efea3
%global shortcommit0 %(c=%{commit0}; echo ${c:0:7})
%global git0 https://%{import_path}

%global service_name crio

Name: %{repo}
Version: 1.20.5
Release: 6.rhaos4.7.git%{shortcommit0}%{?dist}
Summary: Kubernetes Container Runtime Interface for OCI-based containers
License: ASL 2.0
URL: %{git0}
Source0: %{git0}/archive/%{commit0}/%{name}-%{shortcommit0}.tar.gz
Source1: seccomp.json
Source3: %{service_name}-network.sysconfig
Source4: %{service_name}-storage.sysconfig
Source5: %{service_name}-metrics.sysconfig
Source6: %{service_name}.service
%if 0%{?rhel} && ! 0%{?fedora}
BuildRequires: go-toolset-1.%{gominver}
%else
BuildRequires: golang
%endif
BuildRequires: git
BuildRequires: glib2-devel
BuildRequires: glibc-static
BuildRequires: go-md2man
BuildRequires: gpgme-devel
BuildRequires: libassuan-devel
BuildRequires: libseccomp-devel
BuildRequires: make
BuildRequires: pkgconfig(systemd)
Requires(pre): container-selinux
Requires: skopeo-containers >= 1:0.1.40-1
Requires: runc >= 1.0.0-61.rc8
Obsoletes: ocid <= 0.3
Provides: ocid = %{version}-%{release}
Provides: %{service_name} = %{version}-%{release}
Requires: containernetworking-plugins >= 0.8.2-3
Requires: conmon >= 2.0.2-2

%description
%{summary}

%prep
%autosetup -Sgit -n %{name}-%{commit0}
cp %{SOURCE6} contrib/systemd/.
sed -i 's/\.gopathok //' Makefile
sed -i 's/%{version}/%{version}-%{release}/' internal/version/version.go
sed -i 's/\/local//' contrib/systemd/%{service_name}.service
sed -i 's/\/local//' contrib/systemd/%{service_name}-wipe.service

%build
mkdir _output
pushd _output
mkdir -p src/%{provider}.%{provider_tld}/{%{project},opencontainers}
ln -s $(dirs +1 -l) src/%{import_path}
popd

ln -s vendor src
export GOPATH=$(pwd)/_output:$(pwd)
export BUILDTAGS="selinux seccomp exclude_graphdriver_devicemapper exclude_graphdriver_btrfs containers_image_ostree_stub"
export GO111MODULE=off
# https://bugzilla.redhat.com/show_bug.cgi?id=1825623
export VERSION=%{version}
# build crio
%gobuild -o bin/%{service_name} %{import_path}/cmd/%{service_name}

# build crio-status
%gobuild -o bin/crio-status %{import_path}/cmd/crio-status

# build pinns and docs
%{__make} bin/pinns
%if 0%{?rhel} <= 7 && ! 0%{?fedora}
GO_MD2MAN=go-md2man GO="scl enable go-toolset-1.%{gominver} -- go" %{__make} docs
%else
GO_MD2MAN=go-md2man %{__make} docs
%endif

%install
./bin/%{service_name} \
      --selinux \
      --cgroup-manager "systemd" \
      --storage-driver "overlay" \
      --cni-plugin-dir "%{_libexecdir}/cni" \
      --storage-opt "overlay.override_kernel_check=1" \
      config > %{service_name}.conf

# install conf files
install -dp %{buildroot}%{_sysconfdir}/cni/net.d
install -p -m 644 contrib/cni/10-crio-bridge.conf %{buildroot}%{_sysconfdir}/cni/net.d/100-crio-bridge.conf
install -p -m 644 contrib/cni/99-loopback.conf %{buildroot}%{_sysconfdir}/cni/net.d/200-loopback.conf

install -dp %{buildroot}%{_sysconfdir}/sysconfig
#install -p -m 644 contrib/sysconfig/%%{service_name} %%{buildroot}%%{_sysconfdir}/sysconfig/%%{service_name}
install -p -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/sysconfig/%{service_name}-network
install -p -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/sysconfig/%{service_name}-storage
install -p -m 644 %{SOURCE5} %{buildroot}%{_sysconfdir}/sysconfig/%{service_name}-metrics

make PREFIX=%{buildroot}%{_prefix} DESTDIR=%{buildroot} \
            install.bin-nobuild \
            install.completions \
            install.config-nobuild \
            install.man-nobuild \
            install.systemd

# install seccomp.json
install -p -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/%{service_name}/seccomp.json

install -dp %{buildroot}%{_sharedstatedir}/containers
install -dp %{buildroot}%{_sharedstatedir}/cni/bin
install -dp %{buildroot}%{_sysconfdir}/kubernetes/cni/net.d
install -dp %{buildroot}%{_datadir}/containers/oci/hooks.d
install -dp %{buildroot}/opt/cni/bin

%check
%if 0%{?with_check}
export GOPATH=%{buildroot}/%{gopath}:$(pwd)/Godeps/_workspace:%{gopath}
%endif

%post
%systemd_post %{service_name}

%preun
%systemd_preun %{service_name}

%postun
%systemd_postun_with_restart %{service_name}

#define license tag if not already defined
%{!?_licensedir:%global license %doc}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{service_name}
%{_bindir}/%{service_name}-status
%{_bindir}/pinns
%{_mandir}/man5/%{service_name}.conf*5*
%{_mandir}/man8/%{service_name}*.8*
%dir %{_sysconfdir}/%{service_name}
%config(noreplace) %{_sysconfdir}/%{service_name}/%{service_name}.conf
%config(noreplace) %{_sysconfdir}/%{service_name}/seccomp.json
%config(noreplace) %{_sysconfdir}/sysconfig/%{service_name}-storage
%config(noreplace) %{_sysconfdir}/sysconfig/%{service_name}-network
%config(noreplace) %{_sysconfdir}/sysconfig/%{service_name}-metrics
%config(noreplace) %{_sysconfdir}/cni/net.d/100-%{service_name}-bridge.conf
%config(noreplace) %{_sysconfdir}/cni/net.d/200-loopback.conf
%config(noreplace) %{_sysconfdir}/crictl.yaml
%{_unitdir}/%{service_name}.service
%{_unitdir}/%{name}.service
%{_unitdir}/%{service_name}-shutdown.service
%{_unitdir}/%{service_name}-wipe.service
%dir %{_sharedstatedir}/containers
%dir %{_sharedstatedir}/cni
%dir %{_sharedstatedir}/cni/bin
%dir %{_sysconfdir}/kubernetes
%dir %{_sysconfdir}/kubernetes/cni
%dir %{_sysconfdir}/kubernetes/cni/net.d
%dir %{_datadir}/containers
%dir %{_datadir}/containers/oci
%dir %{_datadir}/containers/oci/hooks.d
%dir /opt/cni
%dir /opt/cni/bin
%dir %{_datadir}/oci-umount
%dir %{_datadir}/oci-umount/oci-umount.d
%{_datadir}/oci-umount/oci-umount.d/%{service_name}-umount.conf
%{_datadir}/bash-completion/completions/%{service_name}*
%{_datadir}/fish/completions/%{service_name}*.fish
%{_datadir}/zsh/site-functions/_%{service_name}*

%changelog
* Fri Oct 15 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.5-6.rhaos4.7.gitec973a2
- autobuilt ec973a2

* Thu Oct 14 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.5-5.rhaos4.7.git037c669
- autobuilt 037c669

* Thu Oct 14 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.5-4.rhaos4.7.git14a27db
- autobuilt 14a27db

* Wed Oct 06 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.5-3.rhaos4.7.git5fcc3f9
- autobuilt 5fcc3f9

* Thu Sep 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.5-2.rhaos4.7.git5739238
- bump to 1.20.5
- autobuilt 5739238

* Wed Sep 01 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.4-14.rhaos4.7.gitbce257b
- autobuilt bce257b

* Wed Sep 01 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.4-13.rhaos4.7.gitfd45842
- autobuilt fd45842

* Mon Aug 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.4-12.rhaos4.7.git9275d5c
- autobuilt 9275d5c

* Tue Aug 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.4-11.rhaos4.7.git9d682e1
- autobuilt 9d682e1

* Mon Aug 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.4-10.rhaos4.7.git15ec74e
- autobuilt 15ec74e

* Wed Aug 11 2021 Peter Hunt <pehunt@redhat.com> - 1.20.4-9.rhaos4.7.git74c6592
- use conmon from path

* Thu Aug 05 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.4-8.rhaos4.7.git74c6592
- autobuilt 74c6592

* Fri Jul 30 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.4-7.rhaos4.7.git6287500
- autobuilt 6287500

* Mon Jul 26 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.4-6.rhaos4.7.git3653a41
- autobuilt 3653a41

* Mon Jul 26 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.4-5.rhaos4.7.gitea842fa
- autobuilt ea842fa

* Mon Jul 19 2021 Peter Hunt <pehunt@redhat.com> - 1.20.4-4.rhaos4.7.gitf7276ed
- add kubelet as a dependency in service

* Mon Jul 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.4-3.rhaos4.7.gitf7276ed
- autobuilt f7276ed

* Mon Jul 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.4-2.rhaos4.7.git79071e9
- bump to 1.20.4
- autobuilt 79071e9

* Wed Jul 14 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.3-9.rhaos4.7.git5212621
- autobuilt 5212621

* Mon Jul 12 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.3-8.rhaos4.7.git0addf34
- autobuilt 0addf34

* Mon Jun 28 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.3-7.rhaos4.7.git41925ef
- autobuilt 41925ef

* Fri Jun 25 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.3-6.rhaos4.7.git0d0f863
- autobuilt 0d0f863

* Thu Jun 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.3-5.rhaos4.7.gitbf90cc5
- autobuilt bf90cc5

* Wed Jun 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.3-4.rhaos4.7.gitbaade70
- autobuilt baade70

* Fri Jun 11 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.3-3.rhaos4.7.git845b2fa
- autobuilt 845b2fa

* Thu Jun 03 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.3-2.rhaos4.7.gitb53fa9d
- bump to 1.20.3
- autobuilt b53fa9d

* Fri May 21 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.2-12.rhaos4.7.git9f7be76
- autobuilt 9f7be76

* Wed May 05 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.2-11.rhaos4.7.git704b03d
- autobuilt 704b03d

* Wed Apr 28 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.2-10.rhaos4.7.gitfc8b9e9
- autobuilt fc8b9e9

* Wed Apr 28 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.2-9.rhaos4.7.gitb979f6a
- autobuilt b979f6a

* Wed Apr 28 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.2-8.rhaos4.7.gita2f05e3
- autobuilt a2f05e3

* Tue Apr 27 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.2-7.rhaos4.7.gitf2fcc39
- autobuilt f2fcc39

* Wed Apr 07 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.2-6.rhaos4.7.gitf1d5201
- autobuilt f1d5201

* Tue Apr 06 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.2-5.rhaos4.7.git52f1a6e
- autobuilt 52f1a6e

* Wed Mar 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.2-4.rhaos4.7.gitd5a999a
- autobuilt d5a999a

* Thu Mar 18 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.2-3.rhaos4.7.gitfecc319
- autobuilt fecc319

* Wed Mar 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.2-2.rhaos4.7.git8840cfb
- bump to 1.20.2
- autobuilt 8840cfb

* Wed Mar 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.1-9.rhaos4.7.git221535b
- autobuilt 221535b

* Mon Mar 15 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.1-8.rhaos4.7.gitc987283
- autobuilt c987283

* Mon Mar 15 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.1-7.rhaos4.7.gitf2ca6bd
- autobuilt f2ca6bd

* Fri Mar 12 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.1-6.rhaos4.7.git0e6266b
- autobuilt 0e6266b

* Wed Mar 10 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.1-5.rhaos4.7.git62f21aa
- autobuilt 62f21aa

* Tue Mar 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.1-4.rhaos4.7.gitb2dd803
- autobuilt b2dd803

* Tue Mar 02 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.1-3.rhaos4.7.gita18cf24
- autobuilt a18cf24

* Wed Feb 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.1-2.rhaos4.7.git0c3216a
- bump to 1.20.1
- autobuilt 0c3216a

* Wed Feb 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.gitd2e75f0.57
- autobuilt d2e75f0

* Tue Feb 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git1f21a5a.56
- autobuilt 1f21a5a

* Mon Feb 22 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git70a5def.55
- autobuilt 70a5def

* Tue Feb 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.gitb422fc2.54
- autobuilt b422fc2

* Tue Feb 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.gitf1ab11e.53
- autobuilt f1ab11e

* Tue Feb 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.gitfdbdf43.52
- autobuilt fdbdf43

* Mon Feb 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git8921e00.51
- autobuilt 8921e00

* Mon Feb 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git4de839c.50
- autobuilt 4de839c

* Fri Feb 05 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git78527db.49
- autobuilt 78527db

* Thu Feb 04 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git2ef6415.48
- autobuilt 2ef6415

* Wed Feb 03 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git18f4ba0.47
- autobuilt 18f4ba0

* Wed Feb 03 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git4a37b4e.46
- autobuilt 4a37b4e

* Tue Feb 02 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.gite838816.45
- autobuilt e838816

* Fri Jan 29 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.gitce4f759.44
- autobuilt ce4f759

* Wed Jan 20 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.gita1ab08a.43
- autobuilt a1ab08a

* Fri Jan 15 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.gitd9f17c8.42
- autobuilt d9f17c8

* Thu Jan 14 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git82b3148.41
- autobuilt 82b3148

* Fri Jan 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git845747f.40
- autobuilt 845747f

* Fri Dec 11 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.gitd388528.39
- autobuilt d388528

* Fri Dec 11 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git62afeec.38
- autobuilt 62afeec

* Thu Dec 10 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git209938c.37
- autobuilt 209938c

* Wed Dec 09 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.gitdd82db6.36
- autobuilt dd82db6

* Wed Dec 09 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git9f324ed.35
- autobuilt 9f324ed

* Wed Dec 09 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git0551b1c.34
- autobuilt 0551b1c

* Tue Dec 08 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git20bf416.33
- autobuilt 20bf416

* Tue Dec 08 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git9cfbe39.32
- autobuilt 9cfbe39

* Tue Dec 08 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git98b2d90.31
- autobuilt 98b2d90

* Mon Dec 07 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.gitb03c34a.30
- autobuilt b03c34a

* Sat Dec 05 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.gitb5f76f7.29
- autobuilt b5f76f7

* Fri Dec 04 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git5e58378.28
- autobuilt 5e58378

* Fri Dec 04 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.gite83cd1d.27
- autobuilt e83cd1d

* Thu Dec 03 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git5e950f8.26
- autobuilt 5e950f8

* Thu Dec 03 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git574c25e.25
- autobuilt 574c25e

* Thu Dec 03 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git4dff9dd.24
- autobuilt 4dff9dd

* Wed Dec 02 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git87851ea.23
- autobuilt 87851ea

* Tue Dec 01 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.gitd38c0c9.22
- autobuilt d38c0c9

* Tue Dec 01 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git788777e.21
- autobuilt 788777e

* Mon Nov 30 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git76884d4.20
- autobuilt 76884d4

* Tue Nov 24 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.gitf3390f3.19
- autobuilt f3390f3

* Fri Nov 20 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.gita30d12f.18
- autobuilt a30d12f

* Fri Nov 20 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git61c8b37.17
- autobuilt 61c8b37

* Wed Nov 18 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git0fcc2a5.16
- autobuilt 0fcc2a5

* Tue Nov 17 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git72629e5.15
- autobuilt 72629e5

* Tue Nov 17 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git3873392.14
- autobuilt 3873392

* Tue Nov 17 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.gita004cba.13
- autobuilt a004cba

* Sat Nov 14 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.gitf261f05.12
- autobuilt f261f05

* Thu Nov 12 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git48ee902.11
- autobuilt 48ee902

* Tue Nov 10 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git3b1a241.10
- autobuilt 3b1a241

* Mon Nov 09 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git8e23406.9
- autobuilt 8e23406

* Fri Nov 06 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git943f033.8
- autobuilt 943f033

* Thu Nov 05 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git962790c.7
- autobuilt 962790c

* Tue Nov 03 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git30decce.6
- autobuilt 30decce

* Tue Nov 03 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.gita36fb60.5
- autobuilt a36fb60

* Mon Nov 02 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git7fc26b2.4
- autobuilt 7fc26b2

* Mon Nov 02 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.gitc48a88a.3
- autobuilt c48a88a

* Fri Oct 30 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.gitbfa194c.2
- autobuilt bfa194c

* Wed Oct 28 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-0.rhaos4.7.git0202886.1
- autobuilt 0202886

* Fri Oct 23 2020 Peter Hunt <pehunt@redhat.com> - 1.20.0-0.rhaos4.7.gitec53db4
- Initial 4.7 build

